# Generated by roxygen2: do not edit by hand

export(clean_text)
export(get_aff)
export(get_complex)
export(get_conf)
export(get_ctrl)
export(get_dist)
export(get_lta)
export(get_nat)
export(get_oca)
export(get_power)
export(get_task)
export(type_lta)
import(dplyr)
import(stringr)
import(tidyr)
importFrom(countries,list_countries)
importFrom(countrycode,countryname)
importFrom(data.table,rleid)
importFrom(purrr,map_dfr)
importFrom(spacyr,spacy_parse)
importFrom(stats,na.omit)
importFrom(stats,var)
importFrom(stringi,stri_trans_general)
importFrom(tibble,tibble)
