#' JFK Speech: Inaugural Address (January 20, 1961)
#'
#' Full text of JFK's Inaugural Address on January 20, 1961.
#'
#' @format A character string containing the full text of the speech.
#'
#' @source \url{https://www.govinfo.gov/app/details/PPP-1961-book1}.
#' These original source texts are U.S. government works and are not subject to
#' copyright protection in the United States under 17 U.S.C. § 105.
#' The package authors do not claim copyright in the original presidential speech texts.
"jfk19610120"

#' JFK Speech: Address Before the UN General Assembly (September 25, 1961)
#'
#' Full text of JFK's address before the UN General Assembly on September 25, 1961.
#'
#' @format A character string containing the full text of the speech.
#'
#' @source \url{https://www.govinfo.gov/app/details/PPP-1961-book1}.
#' These original source texts are U.S. government works and are not subject to
#' copyright protection in the United States under 17 U.S.C. § 105.
#' The package authors do not claim copyright in the original presidential speech texts.
"jfk19610925"

#' JFK Speech: Commencement Address at American University (June 10, 1963)
#'
#' Full text of Senator John F. Kennedy's commencement address at American University on June 10, 1963.
#'
#' @format A character string containing the full text of the speech.
#'
#' @source \url{https://www.govinfo.gov/app/details/PPP-1963-book1}.
#' These original source texts are U.S. government works and are not subject to
#' copyright protection in the United States under 17 U.S.C. § 105.
#' The package authors do not claim copyright in the original presidential speech texts.
"jfk19630610"
