% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/complexity.R
\name{strip_quoted}
\alias{strip_quoted}
\title{Strip quoted text from a string}
\usage{
strip_quoted(x)
}
\arguments{
\item{x}{A character string.}
}
\value{
The string with quoted passages removed.
}
\description{
Strip quoted text from a string
}
\keyword{internal}
