% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/expand_aliases.R
\name{io}
\alias{io}
\title{International organizations list}
\usage{
io
}
\description{
A character vector of international organization names and acronyms
used for entity detection across the package.
}
\keyword{internal}
