% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/complexity.R
\name{prep_exact_regex}
\alias{prep_exact_regex}
\title{Prepare exact-word regex pattern}
\usage{
prep_exact_regex(words)
}
\arguments{
\item{words}{Character vector of words to match exactly.}
}
\value{
A single regex string.
}
\description{
Prepare exact-word regex pattern
}
\keyword{internal}
