% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/complexity.R
\name{count_valid}
\alias{count_valid}
\title{Count valid (non-negated) pattern matches}
\usage{
count_valid(txt, pattern, window_chars = 40)
}
\arguments{
\item{txt}{A character string to search.}

\item{pattern}{A regex pattern to match.}

\item{window_chars}{Integer; number of characters to look back for negation.}
}
\value{
Integer count of valid matches.
}
\description{
Count valid (non-negated) pattern matches
}
\keyword{internal}
