% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-entities.R
\name{build_entities_corpus}
\alias{build_entities_corpus}
\title{Build entities corpus for entity matching}
\usage{
build_entities_corpus()
}
\value{
A character vector of entity names.
}
\description{
Constructs a vector of lowercased international organization names and
country names (including aliases) for use in entity detection.
}
\keyword{internal}
